@@ -404,7 +404,7 @@ def virial_quantities(halo, fields, critical_overdensity=200,
                halo.quantities["particle_identifier"])
 
     fields = ensure_list(fields)
-    fields = [halo.halo_catalog.data_source._determine_fields(field)[0]
+    fields = [halo.data_object._determine_fields(field)[0]
               for field in fields]
     
     dds = halo.halo_catalog.data_ds
